krb5 commit: Fix KDC worker process argument parsing

Greg Hudson ghudson at MIT.EDU
Fri Jun 27 16:17:52 EDT 2014


https://github.com/krb5/krb5/commit/1776fd19120d230115527febbd22979eb64ee1ff
commit 1776fd19120d230115527febbd22979eb64ee1ff
Author: Greg Hudson <ghudson at mit.edu>
Date:   Wed Jun 18 12:58:39 2014 -0400

    Fix KDC worker process argument parsing
    
    To create worker processes, the KDC shuts down realms, forks off the
    worker processes, then reinitializes realms in each child.
    Reinitializing realms requires making a second pass over the
    command-line arguments.  To do this with getopt, optind must be
    reinitialized to 1 for each pass; otherwise, no options will be seen
    the second time around.
    
    ticket: 7945
    target_version: 1.12.2
    tags: pullup

 src/kdc/main.c |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)

diff --git a/src/kdc/main.c b/src/kdc/main.c
index c2bc6c2..c3b7b80 100644
--- a/src/kdc/main.c
+++ b/src/kdc/main.c
@@ -665,9 +665,11 @@ initialize_realms(krb5_context kcontext, int argc, char **argv)
     }
 
     /*
      * Loop through the option list.  Each time we encounter a realm name,
      * use the previously scanned options to fill in for defaults.
      */
+    optind = 1;
     while ((c = getopt(argc, argv, "x:r:d:mM:k:R:e:P:p:s:nw:4:T:X3")) != -1) {
         switch(c) {
         case 'x':
@@ -665,9 +665,11 @@ initialize_realms(krb5_context kcontext, int argc, char **argv)
 
     /*
-     * Loop through the option list.  Each time we encounter a realm name,
-     * use the previously scanned options to fill in for defaults.
+     * Loop through the option list.  Each time we encounter a realm name, use
+     * the previously scanned options to fill in for defaults.  We do this
+     * twice if worker processes are used, so we must initialize optind.
      */


More information about the cvs-krb5 mailing list